``sbijax``
==========

.. currentmodule:: sbijax

----

:code:`sbijax` contains the implemented methods for simulation-based inference.

Methods
-------

.. autosummary::
    SMCABC
    SNL
    SNP
    SNR
    SFMPE
    SCMPE
    SNASS
    SNASSS

SMCABC
~~~~~~

..  autoclass:: SMCABC
    :members: fit, simulate_data_and_possibly_append, sample_posterior

SNL+SSNL
~~~~~~~~

..  autoclass:: SNL
    :members: fit, simulate_data_and_possibly_append, sample_posterior

SNP
~~~

..  autoclass:: SNP
    :members: fit, simulate_data_and_possibly_append, sample_posterior

SNR
~~~

..  autoclass:: SNR
    :members: fit, simulate_data_and_possibly_append, sample_posterior

SFMPE
~~~~~

..  autoclass:: SFMPE
    :members: fit, simulate_data_and_possibly_append, sample_posterior

SCMPE
~~~~~

..  autoclass:: SCMPE
    :members: fit, simulate_data_and_possibly_append, sample_posterior

SNASS
~~~~~

..  autoclass:: SNASS
    :members: fit, simulate_data_and_possibly_append, sample_posterior

SNASSS
~~~~~~

..  autoclass:: SNASSS
    :members: fit, simulate_data_and_possibly_append, sample_posterior
